==> nmrium-0.50.1.tgz: package/lib/component/panels/predictionPanel/PredictionPanel.js <==
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { useEffect, useRef, useState } from 'react';
import { ResponsiveChart } from 'react-d3-utils';
import { StructureEditor } from 'react-ocl/full';
import { useAccordionContext } from 'react-science/ui';
import { predictSpectra } from '../../../data/PredictionManager';
import { useChartData } from '../../context/ChartContext';
import { useDispatch } from '../../context/DispatchContext';
import { useLogger } from '../../context/LoggerContext';
import Button from '../../elements/Button';
import NextPrev from '../../elements/NextPrev';
import { useAlert } from '../../elements/popup/Alert';
import { usePanelPreferences } from '../../hooks/usePanelPreferences';
import { useMoleculeEditor } from '../../modal/MoleculeStructureEditorModal';
import MoleculeHeader from '../MoleculesPanel/MoleculeHeader';
import MoleculePanelHeader from '../MoleculesPanel/MoleculePanelHeader';
import { tablePanelStyle } from '../extra/BasicPanelStyle';
import PreferencesHeader from '../header/PreferencesHeader';
import PredictionPreferences from './PredictionPreferences';
import PredictionSimpleOptions from './PredictionSimpleOptions';
const styles = {
    flexColumnContainer: {
        display: 'flex',
        flexDirection: 'column',
        flex: 1,
    },
    slider: {
        overflow: 'hidden auto',
    },
};
export default function PredictionPanel() {
    const { molecules, view: { molecules: moleculesView, predictions }, } = useChartData();
    const dispatch = useDispatch();
    const alert = useAlert();
    const { logger } = useLogger();
    const [currentIndex, setCurrentIndex] = useState(0);
    const [molfile, setMolfile] = useState(null);
    const [isFlipped, setFlipStatus] = useState(false);
    const settingRef = useRef();
    const { item: spectraPanelState, utils: { toggle: openSpectraPanel }, } = useAccordionContext('Spectra');
    const predictionPreferences = usePanelPreferences('prediction');
    const { modal, openMoleculeEditor } = useMoleculeEditor(true);
    const refreshSlider = useRef(false);
    useEffect(() => {
        if (Array.isArray(molecules) &&
            molecules.length > 0 &&
            refreshSlider.current) {
            const newIndex = molecules.length - 1;
            setCurrentIndex(newIndex);
            setMolfile(molecules[newIndex].molfile);
            refreshSlider.current = false;
        }
    }, [molecules]);
    function changeHandler(molfile, molecule) {
        const atoms = molecule.getAllAtoms();
        if (atoms === 0) {
            setMolfile(null);
        }
        else {
            setMolfile(molfile);
        }
    }
    function predictHandler(action) {
        refreshSlider.current = action === 'add';
        void (async () => {
            if (molfile) {
                const predictedSpectra = [];
                for (const [key, value] of Object.entries(predictionPreferences.spectra)) {
                    if (value) {
                        predictedSpectra.push(key);
                    }
                }
                const hideLoading = await alert.showLoading(`Predict ${predictedSpectra.join(',')} in progress`);
                try {
                    const data = await predictSpectra(molfile, predictionPreferences.spectra);
                    dispatch({
                        type: 'PREDICT_SPECTRA',
                        payload: {
                            logger,
                            predictedSpectra: data.spectra,
                            options: predictionPreferences,
                            molecule: { ...molecules[currentIndex], molfile },
                            action,
                        },
                    });
                    if (!spectraPanelState?.isOpen) {
                        openSpectraPanel();
                    }
                }
                catch (error) {
                    alert.error(error.message);
                }
                finally {
                    hideLoading();
                }
            }
            else {
                alert.error('No Molecule selected');
            }
        })();
    }
    function settingsPanelHandler() {
        setFlipStatus(!isFlipped);
    }
    function saveSettingHandler() {
        settingRef.current.saveSetting();
        setFlipStatus(false);
    }
    const isPredictedBefore = !!(molecules[currentIndex]?.id && predictions[molecules[currentIndex].id]);
    return (_jsxs("div", { css: tablePanelStyle, children: [isFlipped && (_jsxs(_Fragment, { children: [_jsx(PreferencesHeader, { onSave: saveSettingHandler, onClose: settingsPanelHandler }), _jsx("div", { className: "inner-container", children: _jsx(PredictionPreferences, { ref: settingRef }) })] })), !isFlipped && (_jsxs(_Fragment, { children: [_jsx(MoleculePanelHeader, { currentIndex: currentIndex, moleculesView: moleculesView, molecules: molecules, renderSource: "predictionPanel", onClickPreferences: settingsPanelHandler, onOpenMoleculeEditor: () => openMoleculeEditor(), onClickPastMolecule: () => {
                            refreshSlider.current = true;
                        }, children: _jsx(PredictionSimpleOptions, {}) }), _jsxs("div", { style: styles.flexColumnContainer, children: [_jsx("div", { style: { flex: 1 }, children: _jsx(ResponsiveChart, { children: ({ height, width }) => {
                                        return (_jsx(NextPrev, { onChange: (slideIndex) => {
                                                setCurrentIndex(slideIndex);
                                                setMolfile(molecules[slideIndex].molfile);
                                            }, defaultIndex: currentIndex, style: {
                                                arrowContainer: {
                                                    top: '40px',
                                                    padding: '0 10px 0 55px',
                                                },
                                            }, children: molecules && molecules.length > 0 ? (molecules.map((mol, molIndex) => (_jsxs("div", { style: styles.flexColumnContainer, children: [_jsx(MoleculeHeader, { currentMolecule: mol, molecules: molecules }), _jsx("div", { style: {
                                                            ...styles.slider,
                                                            height: height - 31,
                                                        }, children: molIndex === currentIndex && (_jsx(StructureEditor, { width: width, initialMolfile: mol.molfile, svgMenu: true, fragment: false, onChange: changeHandler })) })] }, mol.id)))) : (_jsx(StructureEditor, { initialMolfile: molfile || '', width: width, height: height, svgMenu: true, fragment: false, onChange: changeHandler })) }));
                                    } }) }), _jsxs("div", { style: { display: 'flex', padding: '5px' }, children: [_jsx(Button.Done, { onClick: () => predictHandler('save'), disabled: !molfile, children: isPredictedBefore ? 'Replace prediction' : 'Predict spectra' }), isPredictedBefore && (_jsx(Button.Action, { style: { marginLeft: '5px' }, onClick: () => predictHandler('add'), children: "Add prediction" }))] })] })] })), modal] }));
}

==> nmrium-0.53.0.tgz: package/lib/component/panels/predictionPanel/PredictionPanel.js <==
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { useEffect, useRef, useState } from 'react';
import { ResponsiveChart } from 'react-d3-utils';
import { StructureEditor } from 'react-ocl/full';
import { useAccordionContext } from 'react-science/ui';
import { predictSpectra } from '../../../data/PredictionManager';
import { useChartData } from '../../context/ChartContext';
import { useDispatch } from '../../context/DispatchContext';
import { useLogger } from '../../context/LoggerContext';
import { useToaster } from '../../context/ToasterContext';
import Button from '../../elements/Button';
import NextPrev from '../../elements/NextPrev';
import { usePanelPreferences } from '../../hooks/usePanelPreferences';
import { useMoleculeEditor } from '../../modal/MoleculeStructureEditorModal';
import MoleculeHeader from '../MoleculesPanel/MoleculeHeader';
import MoleculePanelHeader from '../MoleculesPanel/MoleculePanelHeader';
import { tablePanelStyle } from '../extra/BasicPanelStyle';
import PreferencesHeader from '../header/PreferencesHeader';
import PredictionPreferences from './PredictionPreferences';
import PredictionSimpleOptions from './PredictionSimpleOptions';
const styles = {
    flexColumnContainer: {
        display: 'flex',
        flexDirection: 'column',
        flex: 1,
    },
    slider: {
        overflow: 'hidden auto',
    },
};
export default function PredictionPanel() {
    const { molecules, view: { molecules: moleculesView, predictions }, } = useChartData();
    const dispatch = useDispatch();
    const toaster = useToaster();
    const { logger } = useLogger();
    const [currentIndex, setCurrentIndex] = useState(0);
    const [molfile, setMolfile] = useState(null);
    const [isFlipped, setFlipStatus] = useState(false);
    const settingRef = useRef();
    const { item: spectraPanelState, utils: { toggle: openSpectraPanel }, } = useAccordionContext('Spectra');
    const predictionPreferences = usePanelPreferences('prediction');
    const { modal, openMoleculeEditor } = useMoleculeEditor(true);
    const refreshSlider = useRef(false);
    useEffect(() => {
        if (Array.isArray(molecules) &&
            molecules.length > 0 &&
            refreshSlider.current) {
            const newIndex = molecules.length - 1;
            setCurrentIndex(newIndex);
            setMolfile(molecules[newIndex].molfile);
            refreshSlider.current = false;
        }
    }, [molecules]);
    function changeHandler(molfile, molecule) {
        const atoms = molecule.getAllAtoms();
        if (atoms === 0) {
            setMolfile(null);
        }
        else {
            setMolfile(molfile);
        }
    }
    function predictHandler(action) {
        refreshSlider.current = action === 'add';
        void (async () => {
            if (molfile) {
                const predictedSpectra = [];
                for (const [key, value] of Object.entries(predictionPreferences.spectra)) {
                    if (value) {
                        predictedSpectra.push(key);
                    }
                }
                const hideLoading = toaster.showLoading({
                    message: `Predict ${predictedSpectra.join(',')} in progress`,
                });
                try {
                    const data = await predictSpectra(molfile, predictionPreferences.spectra);
                    dispatch({
                        type: 'PREDICT_SPECTRA',
                        payload: {
                            logger,
                            predictedSpectra: data.spectra,
                            options: predictionPreferences,
                            molecule: { ...molecules[currentIndex], molfile },
                            action,
                        },
                    });
                    if (!spectraPanelState?.isOpen) {
                        openSpectraPanel();
                    }
                }
                catch (error) {
                    toaster.show({ message: error.message, intent: 'danger' });
                }
                finally {
                    hideLoading();
                }
            }
            else {
                toaster.show({ message: 'No Molecule selected', intent: 'danger' });
            }
        })();
    }
    function settingsPanelHandler() {
        setFlipStatus(!isFlipped);
    }
    function saveSettingHandler() {
        settingRef.current.saveSetting();
        setFlipStatus(false);
    }
    const isPredictedBefore = !!(molecules[currentIndex]?.id && predictions[molecules[currentIndex].id]);
    return (_jsxs("div", { css: tablePanelStyle, children: [isFlipped && (_jsxs(_Fragment, { children: [_jsx(PreferencesHeader, { onSave: saveSettingHandler, onClose: settingsPanelHandler }), _jsx("div", { className: "inner-container", children: _jsx(PredictionPreferences, { ref: settingRef }) })] })), !isFlipped && (_jsxs(_Fragment, { children: [_jsx(MoleculePanelHeader, { currentIndex: currentIndex, moleculesView: moleculesView, molecules: molecules, renderSource: "predictionPanel", onClickPreferences: settingsPanelHandler, onOpenMoleculeEditor: () => openMoleculeEditor(), onClickPastMolecule: () => {
                            refreshSlider.current = true;
                        }, children: _jsx(PredictionSimpleOptions, {}) }), _jsxs("div", { style: styles.flexColumnContainer, children: [_jsx("div", { style: { flex: 1 }, children: _jsx(ResponsiveChart, { children: ({ height, width }) => {
                                        return (_jsx(NextPrev, { onChange: (slideIndex) => {
                                                setCurrentIndex(slideIndex);
                                                setMolfile(molecules[slideIndex].molfile);
                                            }, defaultIndex: currentIndex, style: {
                                                arrowContainer: {
                                                    top: '40px',
                                                    padding: '0 10px 0 55px',
                                                },
                                            }, children: molecules && molecules.length > 0 ? (molecules.map((mol, molIndex) => (_jsxs("div", { style: styles.flexColumnContainer, children: [_jsx(MoleculeHeader, { currentMolecule: mol, molecules: molecules }), _jsx("div", { style: {
                                                            ...styles.slider,
                                                            height: height - 31,
                                                        }, children: molIndex === currentIndex && (_jsx(StructureEditor, { width: width, initialMolfile: mol.molfile, svgMenu: true, fragment: false, onChange: changeHandler })) })] }, mol.id)))) : (_jsx(StructureEditor, { initialMolfile: molfile || '', width: width, height: height, svgMenu: true, fragment: false, onChange: changeHandler })) }));
                                    } }) }), _jsxs("div", { style: { display: 'flex', padding: '5px' }, children: [_jsx(Button.Done, { onClick: () => predictHandler('save'), disabled: !molfile, children: isPredictedBefore ? 'Replace prediction' : 'Predict spectra' }), isPredictedBefore && (_jsx(Button.Action, { style: { marginLeft: '5px' }, onClick: () => predictHandler('add'), children: "Add prediction" }))] })] })] })), modal] }));
}
